==> bower-webpack-plugin-0.1.0.tgz: package/lib/bower-plugin-logger.js <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Lukasz Piepiora <lpiepiora@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

"use strict";

module.exports = Logger;

/**
 * A helper utility to log information
 * @returns {Logger}
 * @constructor
 */
function Logger() {
  if (!(this instanceof Logger)) return new Logger();

  this.logData = [];

}

/**
 * Logs a message
 * @param {string} msg - the message to be logged
 */
Logger.prototype.log = function (msg) {
  this.logData.push("  " + msg);
};

/**
 * Writes out logged information to the callback.log, if such method exists
 * @param callback the callback
 */
Logger.prototype.writeOut = function (callback) {
  if (callback.log)  this.logData.forEach(callback.log, callback);
  this.logData.length = 0;
};

==> bower-webpack-plugin-0.1.6.tgz: package/lib/bower-plugin-logger.js <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014 Lukasz Piepiora <lpiepiora@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

"use strict";

/**
 * A helper utility to log information
 * @returns {Logger}
 * @constructor
 */
function Logger() {
  if (!(this instanceof Logger)) {
    return new Logger();
  }

  this.logData = [];

}

module.exports = Logger;

/**
 * Logs a message
 * @param {string} msg - the message to be logged
 */
Logger.prototype.log = function (msg) {
  this.logData.push("  " + msg);
};

/**
 * Writes out logged information to the callback.log, if such method exists
 * @param callback the callback
 */
Logger.prototype.writeOut = function (callback) {
  if (callback.log) {
    this.logData.forEach(callback.log, callback);
  }
  this.logData.length = 0;
};
